@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -17,9 +20,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-iot-lambda",
-    "2.52.0",
+    "2.56.0",
     __name__[0:-6],
-    "aws-iot-lambda@2.52.0.jsii.tgz",
+    "aws-iot-lambda@2.56.0.jsii.tgz",
 )
 
 __all__ = [
